@@ -14,8 +14,10 @@
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
+import os
 from Download import download_data
 from Process import get_player_stats
+from Plot import Plotter
 from Util import mkdir_p
 
 
@@ -23,3 +25,4 @@ default_dir = os.path.expanduser("~/.fantasy_basketball")
 default_raw_data_dir = os.path.join(default_dir, "raw_data")
 default_processed_data_dir = os.path.join(default_dir, "processed_data")
 default_html_dir = os.path.join(default_dir, "html")
+default_plot_dir = os.path.join(default_dir, "plot")
